<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

defined('_JEXEC') or die;

use Akeeba\Component\ATS\Administrator\Helper\Permissions;
use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Object\CMSObject;
use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Uri\Uri;

/**
 * Joomla editor button plugin for canned replies.
 *
 * This plugin is INTENTIONALLY using the old (pre–Joomla 4) style... because Joomla's editor-xtd plugins ARE NOT REAL
 * PLUGINS. The Joomla\CMS\Editor\Editor class which manages the WYSIWYG editors does not dispatch an onDisplay event
 * via Joomla's application event dispatcher. No, ladies and gentlemen. It get the plugin instance objects AND CALLS
 * THE onDisplay METHOD DIRECTLY. That's how plugins were being called back in the Mambo days (2001–2005) when they were
 * called ‘mambots’.
 *
 * Because of this anachronism we cannot use the Joomla 4 method of going through a service provider. We need to provide
 * a stupid class which extends CMSPlugin so that Joomla can call its onDisplay method directly.
 *
 * @since 3.4.1
 */
class plgButtonAtscannedreplies extends CMSPlugin
{
	/**
	 * The CMS application object
	 *
	 * @var   CMSApplication
	 * @since 5.0.0
	 */
	protected $app;

	/**
	 * Load the language file on instantiation.
	 *
	 * @var    boolean
	 * @since  3.4.0
	 */
	protected $autoloadLanguage = true;

	/** @inheritDoc */
	public function __construct(&$subject, $config = [])
	{
		parent::__construct($subject, $config);
	}

	/**
	 * Display the button
	 *
	 * @param   string  $name  The name of the button to add
	 *
	 * @return  CMSObject|null  The button options as JObject
	 *
	 * @since   3.4.0
	 */
	public function onDisplay($name): ?CMSObject
	{
		// We should only activate when the current component is com_ats
		$option   = $this->app->input->getCmd('option');
		$category = $this->app->getSession()->get('com_ats.cannedreplies.category', null);

		if ($option !== 'com_ats' || !Permissions::isManager($category))
		{
			return null;
		}

		// Pass script options
		$document = $this->app->getDocument();
		$document->addScriptOptions('plg_editors-xtd_atscannedreplies_editor', $name);

		$wam = $document->getWebAssetManager();
		$wam->getRegistry()->addExtensionRegistryFile('plg_editors-xtd_atscannedreplies');
		$wam->useScript('plg_editors-xtd_atscannedreplies.button');

		// Modal options
		// Modal window link
		$link = sprintf(
			'index.php?option=com_ats&view=cannedreplies&layout=%s&tmpl=component&editor=%s',
			$this->app->isClient('site') ? 'default' : 'modal',
			$name
		);

		$image        = HTMLHelper::_('image', 'plg_editors-xtd_atscannedreplies/ats_color.svg', '', '', true, true);
		$image        = $image ? JPATH_ROOT . substr($image, \strlen(Uri::root(true))) : '';
		$imageContent = file_get_contents($image);

		return new CMSObject([
			'modal'   => true,
			'link'    => $link,
			'text'    => Text::_('PLG_EDITORS_XTD_ATSCANNEDREPLIES_BTN_TITLE'),
			'name'    => $this->_type . '_' . $this->_name,
			'icon'    => 'ats-cannedreply',
			'iconSVG' => $imageContent,
			'options' => [
				'height'     => '300px',
				'width'      => '800px',
				'bodyHeight' => '70',
				'modalWidth' => '80',
			],
		]);
	}
}