<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\Controller;

defined('_JEXEC') or die;

use Akeeba\Component\ATS\Administrator\Mixin\ControllerEventsTrait;
use Akeeba\Component\ATS\Administrator\Mixin\ControllerReusableModelsTrait;
use Akeeba\Component\ATS\Administrator\Model\LogModel;
use Joomla\CMS\MVC\Controller\BaseController;

class LogController extends BaseController
{
	use ControllerEventsTrait;
	use ControllerReusableModelsTrait;

	/**
	 * Display the log page
	 *
	 * @return  void
	 *
	 * @since   3.2.0
	 */
	public function display($cachable = false, $urlparams = [])
	{
		/** @var LogModel $model */
		$model = $this->getModel();
		$model->setState('filename', $this->input->getCmd('filename', null) ?: null);

		parent::display(false);
	}

	/**
	 * Download the log file as a text file
	 *
	 * @return  void
	 *
	 * @since   3.2.0
	 */
	public function download()
	{
		/** @var LogModel $model */
		$model = $this->getModel();
		$model->setState('filename', $this->input->getCmd('filename', null) ?: null);

		$asAttachment = $this->input->getBool('attachment', true);

		@ob_end_clean(); // In case some braindead plugin spits its own HTML
		header("Cache-Control: no-cache, must-revalidate"); // HTTP/1.1
		header("Expires: Sat, 26 Jul 1997 05:00:00 GMT"); // Date in the past
		header("Content-Description: File Transfer");
		header('Content-Type: text/plain');

		if ($asAttachment)
		{
			header('Content-Disposition: attachment; filename="Akeeba Ticket System Debug Log.txt"');
		}

		$model->echoRawLog();

		flush();

		$this->app->close();
	}

	/**
	 * Renders the contents of the log, used inside the IFRAME of the log page
	 *
	 * @return  void
	 *
	 * @since   3.2.0
	 */
	public function iframe()
	{
		/** @var LogModel $model */
		$model = $this->getModel();
		$model->setState('filename', $this->input->getCmd('filename', null) ?: null);

		parent::display(false);
	}

	/**
	 * Display the log file as preformatted HTML text
	 *
	 * @return  void
	 *
	 * @since   3.2.0
	 */
	public function inlineRaw()
	{
		/** @var LogModel $model */
		$model = $this->getModel();
		$model->setState('filename', $this->input->getCmd('filename', null) ?: null);

		echo "<pre>";
		$model->echoRawLog();
		echo "</pre>";
	}
}