<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\Controller;

defined('_JEXEC') or die;

use Akeeba\Component\ATS\Administrator\Mixin\ControllerEventsTrait;
use Akeeba\Component\ATS\Administrator\Mixin\ControllerRegisterTasksTrait;
use Akeeba\Component\ATS\Administrator\Mixin\ControllerReusableModelsTrait;
use DateInterval;
use Joomla\CMS\Factory;
use Joomla\CMS\MVC\Controller\BaseController;

class TimecardController extends BaseController
{
	use ControllerEventsTrait;
	use ControllerRegisterTasksTrait;
	use ControllerReusableModelsTrait;

	protected function onBeforeMain()
	{
		// Default: last month
		$now         = clone Factory::getDate();
		$defaultFrom = (clone $now)->setDate($now->year, $now->month, 1)->sub(new DateInterval('P1M'))->setTime(0, 0, 0, 0);

		$from = $defaultFrom;
		$to   = (clone $from)->add(new DateInterval('P1M'));

		// Only apply custom dates if there is a valid anti–CSRF token in the request
		if ($this->checkToken('post', false))
		{
			$fromString = $this->input->getString('from');
			$toString   = $this->input->getString('to');

			try
			{
				$from = $fromString ? clone Factory::getDate($fromString) : $defaultFrom;
			}
			catch (\Exception $e)
			{
				$from = $defaultFrom;
			}

			$defaultTo = (clone $from)->add(new DateInterval('P1M'));

			try
			{
				$to = $toString ? clone Factory::getDate($toString) : $defaultTo;
			}
			catch (\Exception $e)
			{
				$to   = $defaultTo;
			}
		}

		$view       = $this->getView();
		$view->from = $from;
		$view->to   = $to;
	}
}