<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\Helper;

defined('_JEXEC') or die;

use Exception;
use JConfig;
use Joomla\CMS\Factory;

/**
 * Small helper to get Joomla's debug flag in a consistent way
 *
 * @since   3.2.0
 */
abstract class Debug
{
	/**
	 * Get Joomla's debug flag
	 *
	 * @return  bool
	 *
	 * @since   3.2.0
	 */
	public static function getJoomlaDebug(): bool
	{
		// If the JDEBUG constant is defined return its value cast as a boolean
		if (defined('JDEBUG'))
		{
			return (bool) JDEBUG;
		}

		// Joomla 3 & 4 – go through the application object to get the application configuration value
		try
		{
			$app = Factory::getApplication();

			if (method_exists($app, 'get'))
			{
				return (bool) ($app->get('debug', 0));
			}
		}
		catch (Exception $e)
		{
			// Fall through
		}

		// Fallback for Joomla 3 & 4: instantiate JConfig directly
		if (class_exists('JConfig'))
		{
			$config = new JConfig();

			if (property_exists($config, 'debug'))
			{
				return (bool) $config->debug;
			}
		}

		return false;
	}
}