<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\MailAuthentication;

defined('_JEXEC') or die;

interface MailAuthenticationInterface
{
	/**
	 * Get the authentication URL to the OAuth2 consent screen
	 *
	 * @param   string  $clientId  The OAuth2 application's client ID
	 *
	 * @return  string  The URL to redirect to
	 *
	 * @since   5.0.0
	 */
	public function getRedirectionUrl(string $clientId): string;

	/**
	 * Exchange an OAuth2 code for an access and refresh token pair
	 *
	 * @param   string  $code      The single use code returned from the OAuth2 consent page
	 * @param   string  $clientId  The OAuth2 client ID
	 * @param   string  $secret    The OAuth2 secret key
	 *
	 * @return  array{access: string, refresh: ?string}
	 *
	 * @since   5.0.0
	 */
	public function getTokens(string $code, string $clientId, string $secret): array;
}