<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\MailAuthentication;

use Joomla\CMS\Factory;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\Registry\Registry;

defined('_JEXEC') or die;

/**
 * Microsoft Exchange authentication service
 *
 * @since  5.2.0
 * @see    https://learn.microsoft.com/en-us/exchange/client-developer/legacy-protocols/how-to-authenticate-an-imap-pop-smtp-application-by-using-oauth
 */
class Microsoft extends AbstractMailAuthentication
{
	public function __construct()
	{
		// Get the tenant from the URL with a fallback to the session and the plugin configuration (in this order).
		$app           = Factory::getApplication();
		$plugin        = PluginHelper::getPlugin('ats', 'mailfetch');
		$paramsRaw     = $plugin->params ?? '{}';
		$params        = new Registry($paramsRaw);
		$defaultTenant = $app->getSession()->get(
			'com_ats.auth.microsofttenant',
			$params->get('microsoft_tenant', '')
		);
		$tenant        = $app->getInput()->getCmd('tenant', $defaultTenant);

		$this->name   = 'microsoft';
		$this->scopes = [
			'https://outlook.office.com/IMAP.AccessAsUser.All',
			'https://outlook.office.com/POP.AccessAsUser.All',
			'https://outlook.office.com/SMTP.Send',
			'offline_access',
		];
		// See https://learn.microsoft.com/en-us/azure/active-directory/develop/v2-oauth2-auth-code-flow
		$this->urlConsent = sprintf('https://login.microsoftonline.com/%s/oauth2/v2.0/authorize/', $tenant);
		$this->urlToken   = sprintf('https://login.microsoftonline.com/%s/oauth2/v2.0/token/', $tenant);
	}
}