<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\MailAuthentication;

use Throwable;

defined('_JEXEC') or die;

class ServiceErrorException extends \RuntimeException
{
	/**
	 * Create a service error exception.
	 *
	 * @param   string          $error        OAUth2 error type. Use ‘generic’ for a generic or non-OAuth2 error.
	 * @param   string          $description  Detailed error message
	 * @param   string|null     $uri          Redirect to this URL instead of displaying an error page
	 * @param   Throwable|null  $previous     Previous exception
	 */
	public function __construct(string $error = 'generic', string $description = "", ?string $uri = null, Throwable $previous = null)
	{
		$info = [
			'error'       => $error,
			'description' => $description,
			'uri'         => $uri,
		];

		if (empty($uri))
		{
			unset($info['uri']);
		}

		$exceptionMessage = json_encode($info);

		parent::__construct($exceptionMessage, 500, $previous);
	}

}