<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\Model;

defined('_JEXEC') or die;

use Akeeba\Component\ATS\Administrator\Helper\Permissions;
use Akeeba\Component\ATS\Administrator\Mixin\ModelGetItemTrait;
use Akeeba\Component\ATS\Administrator\Table\AttachmentTable;
use Akeeba\Component\ATS\Administrator\Table\PostTable;
use Exception;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\Model\AdminModel;
use RuntimeException;

#[\AllowDynamicProperties]
class AttachmentModel extends AdminModel
{
	use ModelGetItemTrait;

	/**
	 * @inheritDoc
	 */
	public function getForm($data = [], $loadData = true)
	{
		// We do not allow editing / creating an attachment through a web form interface.
		throw new RuntimeException(Text::_('JERROR_ALERTNOAUTHOR'));
	}

	/**
	 * Method to get a single record.
	 *
	 * @param   int|null  $pk  The id of the primary key.
	 *
	 * @return  AttachmentTable|bool  Object on success, false on failure.
	 * @throws  Exception
	 * @since   5.0.0
	 *
	 * @noinspection PhpMissingParentCallCommonInspection
	 */
	public function getItem($pk = null)
	{
		return $this->getItemTable($pk);
	}
	/** @inheritdoc */
	protected function canDelete($record)
	{
		/** @var PostTable $post */
		$post = $this->getTable('Post', 'Administrator');

		if (!empty($record) && isset($record->ticket_id) && empty($record->ticket_id))
		{
			$post->load($record->ticket_id);
		}

		$canDo = Permissions::getPostPrivileges($post);

		return $canDo['delete'] || $canDo['attachment.delete'];
	}

	/** @inheritdoc */
	protected function canEditState($record)
	{
		/** @var PostTable $post */
		$post = $this->getTable('Post', 'Administrator');

		if (!empty($record) && isset($record->ticket_id) && empty($record->ticket_id))
		{
			$post->load($record->ticket_id);
		}

		$canDo = Permissions::getPostPrivileges($post);

		return $canDo['edit.state'] || $canDo['attachment.edit.state'];
	}
}