<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\Model;

defined('_JEXEC') or die;

use Akeeba\Component\ATS\Administrator\Mixin\ModelPopulateStateTrait;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\CMS\MVC\Model\ListModel;
use Joomla\Database\ParameterType;

#[\AllowDynamicProperties]
class AutorepliesModel extends ListModel
{
	use ModelPopulateStateTrait;

	/** @inheritdoc */
	public function __construct($config = [], MVCFactoryInterface $factory = null)
	{
		$config['filter_fields'] = $config['filter_fields'] ?? [
				// Sortable columns (also overlaps with filter columns)
				'id', 'title', 'ordering',
				// Filter–only fields
				'search',
			];

		parent::__construct($config, $factory);

		$this->setupStateFilters([
			'search'  => 'string',
		], 'ordering', 'ASC');
	}

	protected function getListQuery()
	{
		$db    = $this->getDatabase();
		$query = $db->getQuery(true)
			->select('*')
			->from($db->quoteName('#__ats_autoreplies'));

		$search = $this->getState('filter.search');

		if (!empty($search) && is_string($search))
		{
			$search = '%' . $search . '%';
			$query->where($db->quoteName('title') . 'LIKE :search')
				->bind(':search', $search, ParameterType::STRING);
		}

		// List ordering clause
		$orderCol  = $this->state->get('list.ordering', 'ordering');
		$orderDirn = $this->state->get('list.direction', 'ASC');
		$ordering  = $db->escape($orderCol) . ' ' . $db->escape($orderDirn);

		$query->order($ordering);

		return $query;
	}
}