<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\Model;

defined('_JEXEC') or die;

use Akeeba\Component\ATS\Administrator\Mixin\ModelGetItemTrait;
use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Factory;
use Joomla\CMS\MVC\Model\AdminModel;

#[\AllowDynamicProperties]
class AutoreplyModel extends AdminModel
{
	use ModelGetItemTrait;

	/**
	 * @inheritDoc
	 */
	public function getForm($data = [], $loadData = true)
	{
		$form = $this->loadForm(
			'com_ats.autoreply',
			'autoreply',
			[
				'control'   => 'jform',
				'load_data' => $loadData,
			]
		) ?: false;

		if (empty($form))
		{
			return false;
		}

		return $form;
	}

	public function getItem($pk = null)
	{
		return $this->getItemTable($pk);
	}

	protected function loadFormData()
	{
		/** @var CMSApplication $app */
		$app  = Factory::getApplication();
		$data = $app->getUserState('com_ats.edit.autoreply.data', []);

		if (empty($data))
		{
			$data = $this->getItem()->getProperties();
		}

		// Make sure data is an array
		$data = is_object($data) ? $data->getProperties() : $data;

		$data['category'] = $data['category'] ?? $data['params']['categories'] ?? [];

		$this->preprocessData('com_ats.autoreply', $data);

		return $data;
	}

	public function save($data)
	{
		if (is_array($data) && isset($data['category']))
		{
			$recordParams       = $this->getRecordParams($data['id'] ?? null);
			$dataParams         = $data['params'] ?? [];
			$incomingCategories = $data['category'] ?: [];
			$data['params']     = array_merge($recordParams, $dataParams, [
				'categories' => $incomingCategories,
			]);
			unset ($data['category']);
		}

		$params         = $data['params'] ?? [];
		$data['params'] = json_encode($params);

		return parent::save($data);
	}

	private function getRecordParams($id)
	{
		if (empty($id) || (int)$id <= 0)
		{
			return [];
		}

		$item = $this->getItem($id);

		if (!is_object($item))
		{
			return [];
		}

		$rawData = $item->getProperties();

		return $rawData['params'] ?: [];
	}


}