<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\Model;

defined('_JEXEC') or die;

use Akeeba\Component\ATS\Administrator\Mixin\ModelPopulateStateTrait;
use Joomla\CMS\MVC\Factory\MVCFactoryInterface;
use Joomla\CMS\MVC\Model\ListModel;
use Joomla\Database\ParameterType;

#[\AllowDynamicProperties]
class CannedrepliesModel extends ListModel
{
	use ModelPopulateStateTrait;

	/** @inheritdoc */
	public function __construct($config = [], MVCFactoryInterface $factory = null)
	{
		$config['filter_fields'] = $config['filter_fields'] ?? [
				// Sortable columns (also overlaps with filter columns)
				'id', 'title', 'ordering', 'enabled',
				'created', 'created_by', 'modified', 'modified_by', 'checked_out_time', 'checked_out',
				// Filter–only fields
				'search',
			];

		parent::__construct($config, $factory);

		$this->setupStateFilters([
			'enabled' => 'int',
			'search'  => 'string',
		], 'ordering', 'ASC');
	}

	/** @inheritdoc */
	protected function getListQuery()
	{
		$db    = $this->getDatabase();
		$query = $db->getQuery(true)
			->select(['c.*', $db->quoteName('ag.title', 'access_level')])
			->from($db->quoteName('#__ats_cannedreplies', 'c'))
			->join('LEFT', $db->quoteName('#__viewlevels', 'ag'), $db->quoteName('ag.id') . ' = ' . $db->quoteName('c.access'))
		;

		$enabled = $this->getState('filter.enabled');

		if (is_numeric($enabled))
		{
			$query->where($db->quoteName('enabled') . ' = :enabled')
				->bind(':enabled', $enabled, ParameterType::INTEGER);
		}

		$search = $this->getState('filter.search');

		if (!empty($search) && is_string($search))
		{
			$search = '%' . $search . '%';
			$query->where($db->quoteName('title') . 'LIKE :search')
				->bind(':search', $search, ParameterType::STRING);
		}

		$access_levels = $this->getState('filter.access_level');

		if (!empty($access_levels) && is_array($access_levels))
		{
			$access_levels = implode(',', array_map('intval', $access_levels));

			$query->where($db->quoteName('c.access').' IN ('.$access_levels.')');
		}

		// List ordering clause
		$orderCol  = $this->state->get('list.ordering', 'ordering');
		$orderDirn = $this->state->get('list.direction', 'ASC');
		$ordering  = $db->escape($orderCol) . ' ' . $db->escape($orderDirn);

		$query->order($ordering);

		return $query;
	}

}