<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\Model;

use Akeeba\Component\ATS\Administrator\Helper\Permissions;
use Akeeba\Component\ATS\Administrator\Mixin\ModelGetItemTrait;
use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Factory;
use Joomla\CMS\Form\Form;
use Joomla\CMS\MVC\Model\AdminModel;

defined('_JEXEC') or die;

#[\AllowDynamicProperties]
class CannedreplyModel extends AdminModel
{
	use ModelGetItemTrait;

	/**
	 * @inheritDoc
	 */
	public function getForm($data = [], $loadData = true)
	{
		$form = $this->loadForm(
			'com_ats.cannedreply',
			'cannedreply',
			[
				'control'   => 'jform',
				'load_data' => $loadData,
			]
		) ?: false;

		if (empty($form))
		{
			return false;
		}

		$canDo = Permissions::getAclPrivileges();

		$fieldChanges = [
			'ordering'    => $canDo['core.edit.state'] ? '' : 'disable',
			'enabled'     => $canDo['core.edit.state'] ? '' : 'disable',
			'created'     => $canDo['core.admin'] ? '' : 'disable',
			'created_by'  => $canDo['core.admin'] ? '' : 'disable',
			'modified'    => $canDo['core.admin'] ? '' : 'disable',
			'modified_by' => $canDo['core.admin'] ? '' : 'disable',
		];

		array_walk($fieldChanges, function (string $type, string $fieldName, Form $form) {
			switch ($type)
			{
				case 'disable':
					$form->setFieldAttribute($fieldName, 'disabled', 'true');
					$form->setFieldAttribute($fieldName, 'required', 'false');
					$form->setFieldAttribute($fieldName, 'filter', 'unset');
					break;

				case 'remove':
					$form->removeField($fieldName);
					break;
			}
		}, $form);

		return $form;
	}

	public function getItem($pk = null)
	{
		return $this->getItemTable($pk);
	}

	protected function loadFormData()
	{
		/** @var CMSApplication $app */
		$app  = Factory::getApplication();
		$data = $app->getUserState('com_ats.edit.cannedreply.data', []);

		if (empty($data))
		{
			$data = $this->getItem();
		}

		// Make sure data is an array
		$data = is_object($data) ? $data->getProperties() : $data;

		$this->preprocessData('com_ats.cannedreply', $data);

		return $data;
	}


}