<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\Model;

defined('_JEXEC') or die;

use Joomla\CMS\Date\Date;
use Joomla\CMS\Factory;
use Joomla\CMS\MVC\Model\BaseDatabaseModel;
use Joomla\Database\ParameterType;

#[\AllowDynamicProperties]
class TimecardModel extends BaseDatabaseModel
{
	/**
	 * Get the time spent by each user creating a post over a period of time
	 *
	 * @param   Date|null  $from  Start date and time. If null, the date 1 month prior is used.
	 * @param   Date|null  $to    End date and time. If null, the date 1 month after $from is used.
	 *
	 * @return  array  The information about the time spent
	 *
	 * @since   5.0.0
	 */
	public function getTimeCards(?Date $from = null, ?Date $to = null): array
	{
		if (empty($from))
		{
			$from = (clone Factory::getDate())->sub(new \DateInterval('P1M'))->setTime(0, 0, 0, 0);
		}

		if (empty($to))
		{
			$to = (clone $from)->add(new \DateInterval('P1M'));
		}

		$db      = $this->getDatabase();
		$fromSql = $from->toSql($db);
		$toSql   = $to->toSql($db);

		$query = $db->getQuery(true)
			->select([
				$db->quoteName('created_by'),
				'SUM(' . $db->quoteName('timespent') . ') AS ' . $db->quoteName('time'),
				'COUNT(' . $db->quoteName('p.id') . ') AS ' . $db->quoteName('posts'),
			])
			->from($db->quoteName('#__ats_posts', 'p'))
			->where($db->quoteName('timespent') . ' > 0')
			->where($db->quoteName('created') . ' BETWEEN :since AND :to')
			->group($db->quoteName('created_by'))
			->order($db->quoteName('created_by') . 'ASC')
			->bind(':since', $fromSql, ParameterType::STRING)
			->bind(':to', $toSql, ParameterType::STRING);;

		return $db->setQuery($query)->loadAssocList() ?: [];
	}
}