<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\View\Authenticate;

defined('_JEXEC') or die;

use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;

class HtmlView extends BaseHtmlView
{
	/**
	 * Access token to display to the user
	 *
	 * @var   string
	 * @since 5.0.0
	 */
	public $accessToken;

	/**
	 * Error type
	 *
	 * @var   string
	 * @since 5.0.0
	 */
	public $error;

	/**
	 * Detailed error description
	 *
	 * @var   string
	 * @since 5.0.0
	 */
	public $errorDescription;

	/**
	 * Refresh token to display to the user
	 *
	 * @var   string
	 * @since 5.0.0
	 */
	public $refreshToken;

	/**
	 * The internal name of the service we are authenticating to
	 *
	 * @var   string
	 * @since 5.0.0
	 */
	public $service = '';

	public function display($tpl = null)
	{
		$layout = $this->getLayout();

		if ($layout === 'error')
		{
			$this->errorDescription = $this->errorDescription ?: $this->getErrorDescription($this->error);
		}

		parent::display($tpl);
	}

	private function getErrorDescription(string $error): ?string
	{
		if (empty($error))
		{
			return null;
		}

		$key  = sprintf('COM_ATS_AUTHENTICATE_ERR_%s_%s_MESSAGE', strtoupper($this->service), strtoupper($error));
		$text = Text::_($key);

		if ($key !== $text)
		{
			return $text;
		}

		$key  = sprintf('COM_ATS_AUTHENTICATE_ERR_%s_MESSAGE', strtoupper($error));
		$text = Text::_($key);

		return ($key === $text) ? Text::_('COM_ATS_AUTHENTICATE_ERR_GENERIC_MESSAGE') : $text;
	}


}