<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\View\Log;

defined('_JEXEC') or die;

use Akeeba\Component\ATS\Administrator\Model\LogModel;
use Exception;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Toolbar\ToolbarHelper;

class HtmlView extends BaseHtmlView
{
	/**
	 * Big log file threshold: 2Mb
	 */
	const bigLogSize = 2097152;

	/**
	 * Currently selected log file name
	 *
	 * @var   string
	 * @since 3.2.0
	 */
	public $filename;

	/**
	 * Size of the log file
	 *
	 * @var   int
	 * @since 3.2.0
	 */
	public $logSize = 0;

	/**
	 * Is the selected log file too big for being displayed by default?
	 *
	 * @var   bool
	 * @since 3.2.0
	 */
	public $logTooBig = false;

	/**
	 * HtmlHelper list of available log files
	 *
	 * @var   array
	 * @since 3.2.0
	 */
	public $logs = [];

	/**
	 * The main page of the log viewer. It allows you to select a profile to display. When you do it displays the IFRAME
	 * with the actual log content and the button to download the raw log file.
	 *
	 * @return  void
	 * @since   5.0.0
	 */
	public function display($tpl = null)
	{
		// Get a list of log names
		/** @var LogModel $model */
		$model          = $this->getModel();
		$this->logs     = $model->getLogOptions();
		$this->filename = ($model->getState('filename', '') ?: null);

		// Let's check if the file is too big to display
		if ($this->filename)
		{
			try
			{
				$file = $model->getLogPath();

				if (@file_exists($file))
				{
					$this->logSize   = filesize($file);
					$this->logTooBig = ($this->logSize >= self::bigLogSize);
				}
			}
			catch (Exception $e)
			{
				$this->logSize   = 0;
				$this->logTooBig = false;
			}
		}

		$this->document->addScriptOptions('ats.log.tooBig', $this->logTooBig ?: false);
		$this->document->addScriptOptions('ats.log.src', 'index.php?option=com_ats&view=log&task=inlineRaw&filename=' . urlencode($this->filename) . '&tmpl=component');

		$this->document->getWebAssetManager()->useScript('com_ats.log');

		ToolbarHelper::title(Text::_('COM_ATS_TITLE_LOG'), 'icon-ats');
		ToolbarHelper::back('JTOOLBAR_BACK', Route::_('index.php?option=com_ats&view=Controlpanel', false));

		parent::display($tpl);
	}
}