<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\View\Managernote;

defined('_JEXEC') or die;

use Akeeba\Component\ATS\Administrator\Helper\Permissions;
use Akeeba\Component\ATS\Administrator\Mixin\ViewLoadAnyTemplateTrait;
use Akeeba\Component\ATS\Administrator\Model\ManagernoteModel;
use Akeeba\Component\ATS\Administrator\Table\ManagernoteTable;
use Exception;
use Joomla\CMS\Factory;
use Joomla\CMS\Form\Form;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\View\GenericDataException;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\Toolbar\ToolbarHelper;

class HtmlView extends BaseHtmlView
{
	use ViewLoadAnyTemplateTrait;

	/**
	 * The URL to return to after editing
	 *
	 * @var   string|null
	 * @since 5.0.0
	 */
	public $returnUrl;

	/**
	 * Privileges of the currently logged in user for this ticket
	 *
	 * @var   array{view:bool,post:bool,delete:bool,edit:bool,"edit.state":bool,admin:bool,close:bool,attachment:bool}
	 * @since 5.0.0
	 */
	protected $canDo;

	/**
	 * The Form object
	 *
	 * @var    Form
	 * @since  5.0.0
	 */
	protected $form;

	/**
	 * The active item
	 *
	 * @var    ManagernoteTable
	 * @since  5.0.0
	 */
	protected $item;

	/**
	 * The model state
	 *
	 * @var    object
	 * @since  5.0.0
	 */
	protected $state;

	/** @inheritdoc */
	public function display($tpl = null)
	{
		/** @var ManagernoteModel $model */
		$model       = $this->getModel();
		$this->item  = $model->getItem();
		$this->form  = $model->getForm($this->item->getProperties());
		$this->state = $model->getState();

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new GenericDataException(implode("\n", $errors), 500);
		}

		$ticket      = $this->item->getTicket();
		$this->canDo = Permissions::getTicketPrivileges($ticket);

		// Set the category for Canned Replies permissions checks
		Factory::getApplication()->getSession()->set('com_ats.cannedreplies.category', $ticket->catid);

		$this->addToolbar();

		parent::display($tpl);
	}

	/**
	 * Set up Joomla's toolbar.
	 *
	 * @return  void
	 * @throws  Exception
	 * @since   5.0.0
	 */
	protected function addToolbar(): void
	{
		Factory::getApplication()->input->set('hidemainmenu', true);

		$isNew = empty($this->item->id);

		ToolbarHelper::title(Text::_('COM_ATS_TITLE_MANAGERNOTES_' . ($isNew ? 'ADD' : 'EDIT')), 'icon-ats');

		ToolbarHelper::save('managernote.apply');
		ToolbarHelper::apply('managernote.save');

		ToolbarHelper::cancel('managernote.cancel', $isNew ? 'JTOOLBAR_CANCEL' : 'JTOOLBAR_CLOSE');
	}
}