<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

namespace Akeeba\Component\ATS\Administrator\View\Scheduling;

defined('_JEXEC') or die;

use Akeeba\Component\ATS\Administrator\Model\SchedulingModel;
use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Toolbar\ToolbarHelper;

class HtmlView extends BaseHtmlView
{
	/**
	 * Short description of the currently selected command
	 *
	 * @var   string
	 * @since 3.2.0
	 */
	public $commandDescription = '';

	/**
	 * Help text for the currently selected command
	 *
	 * @var   string
	 * @since 3.2.0
	 */
	public $commandHelpText = '';

	/**
	 * Task scheduling information
	 *
	 * @var   object|null
	 * @since 3.2.0
	 */
	public $cronInfo = null;

	/**
	 * Do I have a configured Secret Word for front-end CRON URLs?
	 *
	 * @var   bool
	 * @since 3.2.0
	 */
	public $hasSecretWord = false;

	/**
	 * The proposed Secret Word for front-end CRON URLs
	 *
	 * @var   string
	 * @since 3.2.0
	 */
	public $newSecretWord = '';

	/**
	 * ATS CRON plugin information
	 *
	 * @var   array|null
	 * @since 3.2.0
	 */
	public $plugins = null;

	/**
	 * Currently selected command
	 *
	 * @var   string
	 * @since 3.2.0
	 */
	public $selectedCRONCommand;

	public function display($tpl = null)
	{
		/** @var SchedulingModel $model */
		$model               = $this->getModel();
		$this->cronInfo      = $model->getCRONInfo();
		$this->plugins       = $model->getAtsCronPlugins();
		$this->hasSecretWord = $model->hasSecretWord();

		/** @var CMSApplication $app */
		$app     = Factory::getApplication();
		$session = $app->getSession();

		if (!$this->hasSecretWord)
		{
			$this->newSecretWord = $session->get('ats.cron.newSecretWord', '');
		}

		$this->selectedCRONCommand = $model->getSelectedCRONCommand();
		$allCommands               = $model->getActiveCRONCommands();

		if ($this->selectedCRONCommand == 'commandName')
		{
			$this->commandHelpText    = Text::_('COM_ATS_SCHEDULINGINFO_LBL_COMMANDNAMEGENERIC_DESC');
			$this->commandDescription = Text::_('COM_ATS_SCHEDULINGINFO_LBL_COMMANDNAMEGENERIC_DESC_SHORT');
		}
		else
		{
			$this->commandHelpText    = Text::_($allCommands[$this->selectedCRONCommand]['description']);
			$this->commandDescription = Text::_($allCommands[$this->selectedCRONCommand]['label']);
		}

		ToolbarHelper::title(Text::_('COM_ATS_TITLE_SCHEDULINGINFO'), 'icon-ats');
		ToolbarHelper::back('JTOOLBAR_BACK', Route::_('index.php?option=com_ats&view=Controlpanel', false));

		parent::display($tpl);
	}

	/**
	 * Return the HtmlHelper options for the CRON command drop-down list
	 *
	 * @return  array
	 *
	 * @since   3.2.0
	 */
	public function getCRONCommandOptions()
	{
		/** @var SchedulingModel $model */
		$model = $this->getModel();

		$options = [
			HTMLHelper::_('select.option', 'commandName', 'COM_ATS_SCHEDULINGINFO_LBL_COMMANDNAMEGENERIC_TITLE', [
				'option.label' => 'COM_ATS_SCHEDULINGINFO_LBL_COMMANDNAMEGENERIC_DESC',
			]),
		];

		foreach ($model->getActiveCRONCommands() as $info)
		{
			$options[] = HTMLHelper::_('select.option', $info['command'],
				$info['label'],
				['option.label' => $info['description']]);
		}

		return $options;
	}
}