<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;

/** @var \Akeeba\Component\ATS\Administrator\View\Scheduling\HtmlView $this */

?>

<div class="card border-info mb-3">
	<h3 class="card-header bg-info text-white">
		<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL') ?>
	</h3>

	<div class="card-body">
		<?php if(!trim($this->cronInfo->info->secret)): ?>
		<div class="alert alert-warning">
			<p>
				<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_NOSECRET_PRE') ?>
			</p>
			<p>
				<?= Text::sprintf('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_NOSECRET_SOLUTION', $secret = Factory::getApplication()->getSession()->get('ats.cron.newSecretWord', '')) ?>
			</p>
			<form action="index.php" method="post" id="secretWordForm">
				<input type="hidden" name="option" value="com_ats">
				<input type="hidden" name="view" value="scheduling">
				<input type="hidden" name="task" value="applySecretWord">
				<?= HTMLHelper::_('form.token') ?>

				<button type="submit" class="btn btn-success">
					<span class="icon-ok" aria-hidden="true"></span>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_BTN_CRONURL_NOSECRET_APPLY') ?>
				</button>
			</form>
		</div>
		<?php else: ?>
		<p>
			<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_MANYMETHODS') ?>
		</p>

		<h4 class="mt-4 mb-3 h3 border-bottom">
			<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_TAB_WEBCRON', true) ?>
		</h4>

		<p>
			<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON') ?>
		</p>

		<table class="table table-striped w-100">
			<tbody>
			<tr>
				<td></td>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_INFO') ?>
				</td>
			</tr>
			<tr>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_NAME') ?>
				</td>
				<td>
					<?= Text::sprintf('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_NAME_INFO', $this->commandDescription) ?>
				</td>
			</tr>
			<tr>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_TIMEOUT') ?>
				</td>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_TIMEOUT_INFO') ?>
				</td>
			</tr>
			<tr>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_URL') ?>
				</td>
				<td>
					<p class="user-select-all">
						<?= $this->escape($this->cronInfo->info->root_url) ?>/<?= $this->escape($this->cronInfo->frontend->path) ?>
					</p>

					<?= $this->loadTemplate('clinote') ?>
				</td>
			</tr>
			<tr>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_LOGIN') ?>
				</td>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_LOGINPASSWORD_INFO') ?>
				</td>
			</tr>
			<tr>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_PASSWORD') ?>
				</td>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_LOGINPASSWORD_INFO') ?>
				</td>
			</tr>
			<tr>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_EXECUTIONTIME') ?>
				</td>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_EXECUTIONTIME_INFO') ?>
				</td>
			</tr>
			<tr>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_ALERTS') ?>
				</td>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_ALERTS_INFO') ?>
				</td>
			</tr>
			<tr>
				<td></td>
				<td>
					<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WEBCRON_THENCLICKSUBMIT') ?>
				</td>
			</tr>
			</tbody>
		</table>

		<h4 class="mt-4 mb-3 h3 border-bottom">
			<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_TAB_WGET', true) ?>
		</h4>

		<p>
			<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_WGET') ?>
			<br/>
			<code class="user-select-all">
				wget --max-redirect=10000 "<?= $this->escape($this->cronInfo->info->root_url) ?>/<?= $this->escape($this->cronInfo->frontend->path) ?>" -O - 1>/dev/null 2>/dev/null
			</code>
		</p>

		<?= $this->loadTemplate('clinote') ?>

		<h4 class="mt-4 mb-3 h3 border-bottom">
			<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_TAB_CURL', true) ?>
		</h4>

		<p>
			<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_CURL') ?>
			<br/>
			<code class="user-select-all">
				curl -L --max-redirs 1000 -v "<?= $this->escape($this->cronInfo->info->root_url) ?>/<?= $this->escape($this->cronInfo->frontend->path) ?>" 1>/dev/null 2>/dev/null
			</code>
		</p>

		<?= $this->loadTemplate('clinote') ?>

		<h4 class="mt-4 mb-3 h3 border-bottom">
			<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_TAB_URL', true) ?>
		</h4>

		<p>
			<?= Text::_('COM_ATS_SCHEDULINGINFO_LBL_CRONURL_RAWURL') ?>
			<br/>
			<code class="user-select-all">
				<?= $this->escape($this->cronInfo->info->root_url) ?>/<?= $this->escape($this->cronInfo->frontend->path) ?>
			</code>
		</p>

		<?= $this->loadTemplate('clinote') ?>
		<?php endif ?>
	</div>
</div>