<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

defined('_JEXEC') or die;

/** @var \Akeeba\Component\ATS\Administrator\View\Timecard\HtmlView $this */

use Akeeba\Component\ATS\Administrator\Helper\Permissions;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;

?>

<div class="card">
	<div class="card body p-2">
		<form name="adminForm" id="adminForm"
		      action="<?= Route::_('index.php?option=com_ats&view=Timecard') ?>"
		      method="post"
		>
			<div class="m-2 row g-3 align-items-end">
				<div class="col-auto">
					<label for="autoSizingInput">
						<?= Text::_('COM_ATS_TIMECARD_LBL_FROMDATE') ?>
					</label>
					<?= HTMLHelper::_('calendar', $this->from ?? '', 'from', 'from') ?>
				</div>
				<div class="col-auto">
					<label for="autoSizingInput">
						<?= Text::_('COM_ATS_TIMECARD_LBL_TODATE') ?>
					</label>
					<?= HTMLHelper::_('calendar', $this->to ?? '', 'to', 'to') ?>
				</div>
				<div class="col-auto">
					<button type="submit"
					        class="btn btn-primary">
						<span class="fa fa-sync" aria-hidden="true"></span>
						<?= Text::_('COM_ATS_TIMECARD_LBL_RELOAD') ?>
					</button>
				</div>
			</div>

			<?= HTMLHelper::_('form.token') ?>
		</form>


		<?php if (!empty($this->timeCards)): ?>
			<table class="table table-striped">
			<caption class="visually-hidden">
				<?= Text::_('COM_ATS_TIMECARD_LBL_TABLE_CAPTION') ?>
			</caption>
			<thead>
			<tr>
				<th scope="col">
					<?= Text::_('COM_ATS_TIMECARD_LBL_MANAGER') ?>
				</th>
				<th scope="col">
					<?= Text::_('COM_ATS_TIMECARD_LBL_TIME_MINUTES') ?>
				</th>
				<th scope="col">
					<?= Text::_('COM_ATS_TIMECARD_LBL_TIME_HOURS') ?>
				</th>
				<th scope="col">
					<?= Text::_('COM_ATS_TIMECARD_LBL_POSTS') ?>
				</th>
			</tr>
			</thead>
			<tbody>
			<?php foreach($this->timeCards as $entry): ?>
			<tr>
				<th scope="row">
					<?= Permissions::getUser($entry['created_by'])->name ?>
				</th>
				<td>
					<?= sprintf('%0.2f', $entry['time']) ?>
				</td>
				<td>
					<?= sprintf('%0.2f', $entry['time'] / 60) ?>
				</td>
				<td>
					<?= (int) $entry['posts'] ?>
				</td>
			</tr>
			<?php endforeach; ?>
			</tbody>
			</table>
		<?php else: ?>
			<div class="alert alert-info">
				<?= Text::_('COM_ATS_TIMECARD_LBL_NOINFORMATION') ?>
			</div>
		<?php endif; ?>
	</div>
</div>
