<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

defined('_JEXEC') || die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;

/** @var \Akeeba\Component\ATS\Administrator\View\Cannedreplies\HtmlView $this */

HTMLHelper::_('behavior.multiselect');
HTMLHelper::_('bootstrap.collapse');
HTMLHelper::_('bootstrap.tooltip', '.atsTooltip');

$listOrder = $this->escape($this->state->get('list.ordering'));
$listDirn  = $this->escape($this->state->get('list.direction'));

$i = 0;

$this->document->getWebAssetManager()->useScript('com_ats.cannedreply');

?>
<form action="<?= Route::_('index.php?option=com_ats&view=Cannedreplies&layout=modal&tmpl=component&editor=' . ($this->editor ?? '')); ?>"
	  class="ats ats-cannedreplies ats-cannedreplies-modal"
	  method="post" name="adminForm" id="adminForm">
	<div class="row">
		<div class="col-md-12">
			<div id="j-main-container" class="j-main-container">
				<?php if (empty($this->items)) : ?>
					<div class="alert alert-info">
						<span class="icon-info-circle" aria-hidden="true"></span><span
								class="visually-hidden"><?= Text::_('INFO'); ?></span>
						<?= Text::_('JGLOBAL_NO_MATCHING_RESULTS'); ?>
					</div>
				<?php else : ?>
					<table class="table" id="articleList">
						<caption class="visually-hidden">
							<?= Text::_('COM_ATS_CANNEDREPLIES_TABLE_CAPTION'); ?>, <span
									id="orderedBy"><?= Text::_('JGLOBAL_SORTED_BY'); ?> </span>, <span
									id="filteredBy"><?= Text::_('JGLOBAL_FILTERED_BY'); ?></span>
						</caption>
						<thead>
						<tr>
							<th scope="col">
								<?= HTMLHelper::_('searchtools.sort', 'COM_ATS_TICKETS_LBL_CANNEDREPLY_TITLE_LABEL', 'title', $listDirn, $listOrder); ?>
							</th>

							<th scope="col" class="w-1 d-none d-md-table-cell">
								<?= HTMLHelper::_('searchtools.sort', 'JGRID_HEADING_ID', 'id', $listDirn, $listOrder); ?>
							</th>
						</tr>
						</thead>
						<tbody>
						<?php foreach ($this->items as $item) : ?>
							<tr class="row<?= $i++ % 2; ?>" data-draggable-group="0">
								<td>
									<div>
										<button type="button"
												class="btn btn-dark btn-sm me-2 atsTooltip"
												data-cannedreplyid="<?= $item->id ?>"
												data-bs-toggle="collapse"
												data-bs-target="#atsreply<?= $item->id ?>"
												aria-controls="atsreply<?= $item->id ?>"
												aria-expanded="false"
										>
											<span class="fa fa-expand" aria-hidden="true"></span>
											<span class="visually-hidden">Expand</span>
										</button>

										<button type="button"
												class="btn btn-primary btn-sm me-2 atsCannedReplyUse atsTooltip"
												data-cannedreplyid="<?= $item->id ?>"
										>
											<span class="fa fa-check-circle" aria-hidden="true"></span>
											<span class="visually-hidden">Use This</span>
										</button>

										<?= $this->escape($item->title); ?>
									</div>
									<div id="atsreply<?= $item->id ?>" class="collapse m-1 border p-3 rounded-3">
										<?= $this->rebaseLinks($item->reply) ?>
									</div>
								</td>

								<td class="w-1 d-none d-md-table-cell">
									<?= $item->id ?>
								</td>
							</tr>
						<?php endforeach; ?>
						</tbody>
					</table>

					<?php // Load the pagination. ?>
					<?= $this->pagination->getListFooter(); ?>
				<?php endif; ?>

				<input type="hidden" name="task" value=""> <input type="hidden" name="boxchecked" value="0">
				<?= HTMLHelper::_('form.token'); ?>
			</div>
		</div>
	</div>
</form>
