<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2023 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU General Public License version 3, or later
 */

declare(strict_types=1);

// Evil trick to handle cases Rector can't handle on its own
if ((php_sapi_name() === 'cli') && file_exists('composer.phar'))
{
	function recursiveReplace(string $path)
	{
		if (is_dir($path))
		{
			/** @var DirectoryIterator $entry */
			foreach (new DirectoryIterator($path) as $entry)
			{
				if (($entry->isDir() && !$entry->isDot()) || $entry->isFile())
				{
					recursiveReplace($entry->getPathname());
				}
			}

			return;
		}

		$fileData     = file_get_contents($path);
		$totalChanges = 0;

		// Translation.php files have hardcoded paths in self::$_directory
		if (basename($path) === 'Translation.php')
		{
			$fromPattern = '#self::\$_directory\s*=.*;#iu';
			$toPattern = (strpos($fileData, 'Horde_Imap_Client_Translation') === false) ?
				'self::$_directory = __DIR__ . \'/../../data/locale\';' :
				'self::$_directory = __DIR__ . \'/../../../data/locale\';';
			$fileData = preg_replace($fromPattern, $toPattern, $fileData, -1, $numChanges) ?? $fileData;
			$totalChanges += $numChanges;
		}

		// PHP 7: Dynamic property names coming from array values need to be wrapped in braces.
		$fromPattern = '#->(\$[a-z_][a-z0-9_]*\[.*\])#iu';
		$toPattern   = '->{\1}';
		$fileData = preg_replace($fromPattern, $toPattern, $fileData, -1, $numChanges) ?? $fileData;
		$totalChanges += $numChanges;

		// PHP 8.2+: utf8_encode and _decode are deprecated
		$numChanges = 0;
		$fileData = str_replace('utf8_encode', '\Joomla\Plugin\Ats\Mailfetch\Util\Utf8::utf8_encode', $fileData, $numChanges);
		$totalChanges += $numChanges;
		$fileData = str_replace('utf8_decode', '\Joomla\Plugin\Ats\Mailfetch\Util\Utf8::utf8_decode', $fileData, $numChanges);
		$totalChanges += $numChanges;

		if ($totalChanges && !empty($fileData))
		{
			file_put_contents($path, $fileData);
		}
	}

	recursiveReplace(__DIR__ . '/vendor/pear-pear.horde.org');

	return;
}

defined('__RECTOR_RUNNING__') or die;

use Rector\Core\Configuration\Option;
use Rector\Php70\Rector\Variable\WrapVariableVariableNameInCurlyBracesRector;
use Rector\Php72\Rector\Assign\ListEachRector;
use Rector\Php72\Rector\Assign\ReplaceEachAssignmentWithKeyCurrentRector;
use Rector\Php72\Rector\While_\WhileEachToForeachRector;
use Rector\Set\ValueObject\SetList;
use Symfony\Component\DependencyInjection\Loader\Configurator\ContainerConfigurator;

return static function (ContainerConfigurator $containerConfigurator): void {
	// get parameters
	$parameters = $containerConfigurator->parameters();
	$parameters->set(Option::PATHS, [
		__DIR__ . '/vendor/pear-pear.horde.org',
	]);
	$parameters->set(Option::SKIP, [
		__DIR__ . '/vendor/pear-pear.horde.org/Horde_Exception/data',
		__DIR__ . '/vendor/pear-pear.horde.org/Horde_Imap_Client/data',
		__DIR__ . '/vendor/pear-pear.horde.org/Horde_Imap_Client/Horde/Imap/Client/Cache/Backend/Mongo.php',
		__DIR__ . '/vendor/pear-pear.horde.org/Horde_Mime/data',
	]);

	// Define what rule sets will be applied
	// $containerConfigurator->import(SetList::PHP_70);

	// get services (needed for register a single rule)
	$services = $containerConfigurator->services();

	// register a single rule
	$services->set(WhileEachToForeachRector::class);
};
